@@ -1,11 +1,11 @@
-our $VERSION = '1.11'; # VERSION
-
 ################################################
 package NpsSDK::TimeoutException;
 
+our $VERSION = '1.4'; # VERSION
 sub new { 
     my $self = {};
     bless ($self, "NpsSDK::TimeoutException");
+    print "Timeout Error \n";
     return $self;
 }
 
@@ -22,6 +22,7 @@ package NpsSDK::ConnectionException;
 sub new { 
     my $self = {};
     bless ($self, "NpsSDK::ConnectionException");
+    print "Connection Error \n";
     return $self;
 }
 
@@ -38,6 +39,7 @@ package NpsSDK::UnknownError;
 sub new{
     my $self = shift;
     bless ($self, "NpsSDK::UnknownError");
+    print "Unknown Error \n";
     return $self;
 }
 
