@@ -1,5 +1,7 @@
 package NpsSDK::SoapClient;
 
+
+
 use warnings; 
 use strict;
 
@@ -8,11 +10,9 @@ use NpsSDK::Utils;
 use NpsSDK::Constants; 
 use NpsSDK::Errors;
 
-use Data::Structure::Util qw( unbless );
+use Data::Structure::Util qw( unbless ); 
 
-use Encode qw(encode);
-
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.4'; # VERSION
 
 my $connection; 
 my $response; 
@@ -20,17 +20,25 @@ my $error;
 
 sub _setup {
     my $self = shift;
-    if (defined $NpsSDK::Configuration::logger) {
-        NpsSDK::LogException->error if ($NpsSDK::Configuration::logger->is_debug() and 
+    if (defined $NpsSDK::Configuration::logger) { 
+        NpsSDK::LogException->error if ($NpsSDK::Configuration::log_level eq $NpsSDK::Constants::DEBUG and 
                                 $NpsSDK::Configuration::environment eq $NpsSDK::Constants::PRODUCTION_ENV); 
 
+    if ($NpsSDK::Configuration::log_level > $NpsSDK::Constants::DEBUG){
         eval {  require SOAP::Lite;
                 SOAP::Lite->import(+trace => [ transport => sub {
                 my ($http_object) = @_;
-                NpsSDK::Utils::log_data($http_object);
+                NpsSDK::Utils::masking_func($http_object, \&NpsSDK::Utils::mask_data);
                 }]);
              }
-
+        } else {
+        eval {  require SOAP::Lite;
+                SOAP::Lite->import(+trace => [ transport => sub {
+                my ($http_object) = @_;
+                NpsSDK::Utils::masking_func($http_object, sub{return $_[0]});
+                }]);
+             }
+        }
     } else {
         use SOAP::Lite;
     }
@@ -91,13 +99,10 @@ sub soap_call {
     
     if (defined $error) {
         if ($error == 1) {
-            $NpsSDK::Configuration::logger->warn(encode("UTF-8", "Timeout error"));
             return NpsSDK::TimeoutException->new();
         } elsif ($error == 2 ) {
-            $NpsSDK::Configuration::logger->warn(encode("UTF-8", "Connection error"));
             return NpsSDK::ConnectionException->new();
         } else {
-            $NpsSDK::Configuration::logger->error(encode("UTF-8", "Unknown error"));
             return NpsSDK::UnknownError->new();
         }
     } else {
