@@ -15,9 +15,7 @@ use Digest::MD5 qw(md5_hex);
 use XML::Twig; 
 use XML::Parser; 
 
-use Data::Dumper; use Data::UUID; $Data::Dumper::Terse = 1; 
-
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.4'; # VERSION
 
 sub add_extra_info {
     my ($service, $ref_params) = @_;
@@ -28,7 +26,7 @@ sub add_extra_info {
     return \%params if(exists($hash_merch_services{$service}));
 
     my %info = (
-        SdkInfo => join " ", $NpsSDK::Constants::LANGUAGE, "SDK", "Version:", $NpsSDK::Version::VERSION,
+        SdkInfo => join " ", $NpsSDK::Constants::LANGUAGE, $NpsSDK::Version::VERSION,
     );
 
     my $merch_details_key = "psp_MerchantAdditionalDetails";
@@ -44,27 +42,15 @@ sub add_extra_info {
 sub add_secure_hash {
     my ($secret_key, $ref_params) = @_;
     delete $ref_params->{"psp_SecureHash"} if (exists $ref_params->{"psp_SecureHash"});
-    my $secure_hash= create_hmac_sha256_hash($secret_key, order_collection(%{$ref_params}));
+    my $secure_hash = create_secure_hash($secret_key, $ref_params);
     $ref_params->{"psp_SecureHash"} = $secure_hash;
     return $ref_params;
 }
 
-sub create_md5_hash {
+sub create_secure_hash {
     my ($secret_key, $ref_params) = @_;
     my %params = %{$ref_params};
-    return md5_hex(order_collection(%params).$secret_key);
-}
-
-sub create_hmac_sha256_hash {
-    use Digest::SHA qw(hmac_sha256_hex);
-    my ($secret_key, $ref_params) = @_;
-    return hmac_sha256_hex($ref_params, $secret_key);
-}
-
-sub create_hmac_sha512_hash {
-    use Digest::SHA qw(hmac_sha512_hex);
-    my ($secret_key, $ref_params) = @_;
-    return hmac_sha512_hex($ref_params, $secret_key);
+    return md5_hex(order_collection(%params) . $secret_key);
 }
 
 sub order_collection {
@@ -233,26 +219,17 @@ sub replace_cvcs {
     return $data;
 }
 
-sub log_data {
-    my ($http_object) = @_;
-    my $xml_debug = XML::Twig->new(pretty_print => 'indented');
-    my $xml_info = XML::Twig->new(pretty_print => 'indented');
-
+sub masking_func {
+    my ($http_object, $func) = @_;
+    my $xml = XML::Twig->new(pretty_print => 'indented');
+    my $xml_to_parse = $func->($http_object->content);
     if (ref($http_object) eq "HTTP::Request") {
-        show_logs($http_object, $xml_debug, $xml_info);
+        $xml->safe_parse($xml_to_parse);
+        $NpsSDK::Configuration::logger->info(encode("UTF-8", $xml->sprint())); print "\n";		
+    } elsif (ref($http_object) eq "HTTP::Response") {
+        $xml->safe_parse($xml_to_parse);
+        $NpsSDK::Configuration::logger->info(encode("UTF-8", $xml->sprint()));
     }
-
-    if (ref($http_object) eq "HTTP::Response" and $http_object->code ne 500) {
-        show_logs($http_object, $xml_debug, $xml_info);
-    }
-}
-
-sub show_logs {
-    my ($object, $debug, $info) = @_;
-    $debug->safe_parse($object->content);
-    $info->safe_parse(mask_data($object->content));
-    $NpsSDK::Configuration::logger->debug(encode("UTF-8", ref($object) . " " . $debug->sprint()));
-    $NpsSDK::Configuration::logger->info(encode("UTF-8", ref($object) . " " . $info->sprint()));
 }
 
 sub encode_params {
